@@ -15,7 +15,7 @@ None of the methods will do anything useful.
 
 =cut
 
-our $VERSION = 'v0.71.0';
+our $VERSION = 'v0.71.1';
 
 
 
@@ -27,7 +27,7 @@ sub new { bless {} }
 
 
 
-sub close { }
+sub close { shift }
 
 sub get_span {
     OpenTracing::Implementation::NoOp::Span->new( )
